@@ -1,4 +1,4 @@
-__version__ = "0.1.15"
+__version__ = "0.7.2"
 
 from .wildewidgets import (
     AltairChart,
@@ -10,15 +10,20 @@ from .wildewidgets import (
     HorizontalHistogram,
     HorizontalStackedBarChart,
     LightMenu,
+    MenuMixin,
     PieChart,
     StackedBarChart, 
+    TabbedWidget,
+    TemplateWidget,
     WildewidgetDispatch,
 )
 
-try:
-    from .wildewidgets import (
-        DataTable,
-        DataTableFilter,
-    )
-except ImportError:
-    pass
\ No newline at end of file
+from .tables import (
+    BasicModelTable,
+    DataTable,
+    DataTableFilter,
+)
+
+from .views import (
+    TableActionFormView,
+)
\ No newline at end of file
